@@ -9,9 +9,8 @@
 # This file is part of BayesPy.
 #
 # BayesPy is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# under the terms of the GNU General Public License version 3 as
+# published by the Free Software Foundation.
 #
 # BayesPy is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,4 +21,30 @@
 # along with BayesPy.  If not, see <http://www.gnu.org/licenses/>.
 ######################################################################
 
+"""
+Package for Bayesian inference engines
+
+Inference engines
+-----------------
+
+.. autosummary::
+   :toctree: generated/
+
+   VB
+
+Parameter expansions
+--------------------
+
+.. autosummary::
+   :toctree: generated/
+
+   vmp.transformations.RotationOptimizer
+   vmp.transformations.RotateGaussian
+   vmp.transformations.RotateGaussianARD
+   vmp.transformations.RotateGaussianMarkovChain
+   vmp.transformations.RotateSwitchingMarkovChain
+   vmp.transformations.RotateVaryingMarkovChain
+   vmp.transformations.RotateMultiple
+"""
+
 from .vmp.vmp import VB
